@@ -6,7 +6,7 @@ import asyncio
 from typing import ClassVar, Dict, List, Optional
 
 from pyplumio import util
-from pyplumio.const import AddressTypes
+from pyplumio.const import DeviceType
 from pyplumio.exceptions import ParameterNotFoundError, UnknownDeviceError
 from pyplumio.frames import Frame
 from pyplumio.helpers.parameter import Parameter
@@ -25,8 +25,8 @@ def _handler_class_path(device_type_name: str) -> str:
 # Dictionary of device handler classes indexed by device types.
 # example: "69: ecomax.EcoMAX"
 DEVICE_TYPES: Dict[int, str] = {
-    address_type.value: _handler_class_path(address_type.name)
-    for address_type in AddressTypes
+    device_type.value: _handler_class_path(device_type.name)
+    for device_type in DeviceType
 }
 
 
@@ -58,7 +58,7 @@ class BaseDevice(ABC, TaskManager):
             await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
 
         value = self.data[name]
-        return int(value) if isinstance(value, Parameter) else value
+        return value.value if isinstance(value, Parameter) else value
 
     async def set_value(
         self,
@@ -161,9 +161,20 @@ class Device(BaseDevice):
 class Mixer(BaseDevice):
     """Represents the mixer device."""
 
-    mixer_number: int
+    index: int
 
-    def __init__(self, mixer_number: int = 0):
+    def __init__(self, index: int = 0):
         """Initialize new Mixer object."""
         super().__init__()
-        self.mixer_number = mixer_number
+        self.index = index
+
+
+class Thermostat(BaseDevice):
+    """Represent the thermostat device."""
+
+    index: int
+
+    def __init__(self, index: int = 0):
+        """Initialize new Thermostat object."""
+        super().__init__()
+        self.index = index
