@@ -5,30 +5,19 @@ import asyncio
 from collections.abc import Sequence
 import logging
 import time
-from typing import ClassVar, Final, Tuple
+from typing import ClassVar, Final, Optional, Tuple
 
 from pyplumio.const import (
-    ATTR_ECOMAX_PARAMETERS,
-    ATTR_ECOMAX_SENSORS,
-    ATTR_FRAME_VERSIONS,
-    ATTR_FUEL_BURNED,
-    ATTR_FUEL_CONSUMPTION,
-    ATTR_MIXER_PARAMETERS,
-    ATTR_MIXER_SENSORS,
-    ATTR_MIXERS,
-    ATTR_MODE,
     ATTR_PARAMETER,
-    ATTR_PRODUCT,
-    ATTR_REGDATA,
     ATTR_SCHEDULE,
-    ATTR_SCHEDULES,
-    ATTR_SCHEMA,
+    ATTR_SENSORS,
+    ATTR_STATE,
     ATTR_SWITCH,
-    AddressTypes,
-    FrameTypes,
+    DeviceState,
+    DeviceType,
+    FrameType,
 )
-from pyplumio.devices import Device, Mixer
-from pyplumio.helpers.data_types import Boolean
+from pyplumio.devices import Device, Mixer, Thermostat
 from pyplumio.helpers.filters import on_change
 from pyplumio.helpers.frame_versions import DEFAULT_FRAME_VERSION, FrameVersions
 from pyplumio.helpers.parameter import (
@@ -38,21 +27,42 @@ from pyplumio.helpers.parameter import (
     MixerParameter,
     ScheduleBinaryParameter,
     ScheduleParameter,
+    ThermostatBinaryParameter,
+    ThermostatParameter,
     is_binary_parameter,
 )
-from pyplumio.helpers.product_info import ProductTypes
+from pyplumio.helpers.product_info import ProductType
 from pyplumio.helpers.schedule import Schedule, ScheduleDay
 from pyplumio.helpers.typing import DeviceDataType, ParameterDataType, VersionsInfoType
+from pyplumio.structures import StructureDecoder
 from pyplumio.structures.ecomax_parameters import (
+    ATTR_ECOMAX_CONTROL,
+    ATTR_ECOMAX_PARAMETERS,
     ECOMAX_I_PARAMETERS,
     ECOMAX_P_PARAMETERS,
-    PARAMETER_BOILER_CONTROL,
-    PARAMETER_ECOMAX_CONTROL,
 )
+from pyplumio.structures.frame_versions import ATTR_FRAME_VERSIONS
+from pyplumio.structures.fuel_consumption import ATTR_FUEL_CONSUMPTION
 from pyplumio.structures.mixer_parameters import (
+    ATTR_MIXER_PARAMETERS,
     ECOMAX_I_MIXER_PARAMETERS,
     ECOMAX_P_MIXER_PARAMETERS,
 )
+from pyplumio.structures.mixer_sensors import ATTR_MIXER_SENSORS
+from pyplumio.structures.product_info import ATTR_PRODUCT
+from pyplumio.structures.regulator_data import ATTR_REGDATA, ATTR_REGDATA_DECODER
+from pyplumio.structures.schedules import ATTR_SCHEDULES
+from pyplumio.structures.thermostat_parameters import (
+    ATTR_THERMOSTAT_PARAMETERS,
+    ATTR_THERMOSTAT_PARAMETERS_DECODER,
+    ATTR_THERMOSTAT_PROFILE,
+    THERMOSTAT_PARAMETERS,
+)
+from pyplumio.structures.thermostat_sensors import ATTR_THERMOSTAT_SENSORS
+
+ATTR_MIXERS: Final = "mixers"
+ATTR_THERMOSTATS: Final = "thermostats"
+ATTR_FUEL_BURNED: Final = "fuel_burned"
 
 MAX_TIME_SINCE_LAST_FUEL_DATA: Final = 300
 
@@ -62,17 +72,18 @@ _LOGGER = logging.getLogger(__name__)
 class EcoMAX(Device):
     """Represents ecoMAX controller."""
 
-    address: ClassVar[int] = AddressTypes.ECOMAX
+    address: ClassVar[int] = DeviceType.ECOMAX
     _frame_versions: FrameVersions
     _fuel_burned_timestamp: float = 0.0
     _required_frames: Sequence[int] = (
-        FrameTypes.REQUEST_UID,
-        FrameTypes.REQUEST_DATA_SCHEMA,
-        FrameTypes.REQUEST_ECOMAX_PARAMETERS,
-        FrameTypes.REQUEST_MIXER_PARAMETERS,
-        FrameTypes.REQUEST_PASSWORD,
-        FrameTypes.REQUEST_ALERTS,
-        FrameTypes.REQUEST_SCHEDULES,
+        FrameType.REQUEST_UID,
+        FrameType.REQUEST_DATA_SCHEMA,
+        FrameType.REQUEST_ECOMAX_PARAMETERS,
+        FrameType.REQUEST_MIXER_PARAMETERS,
+        FrameType.REQUEST_PASSWORD,
+        FrameType.REQUEST_ALERTS,
+        FrameType.REQUEST_SCHEDULES,
+        FrameType.REQUEST_THERMOSTAT_PARAMETERS,
     )
 
     def __init__(self, queue: asyncio.Queue):
@@ -80,16 +91,22 @@ class EcoMAX(Device):
         super().__init__(queue)
         self._frame_versions = FrameVersions(device=self)
         self._fuel_burned_timestamp = time.time()
-        self.subscribe(ATTR_ECOMAX_SENSORS, self._add_ecomax_sensors)
-        self.subscribe(ATTR_MODE, on_change(self._add_ecomax_control_parameter))
+        self.subscribe_once(ATTR_FRAME_VERSIONS, self._merge_required_frames)
+        self.subscribe(ATTR_SENSORS, self._add_ecomax_sensors)
+        self.subscribe(ATTR_STATE, on_change(self._add_ecomax_control_parameter))
         self.subscribe(ATTR_FUEL_CONSUMPTION, self._add_burned_fuel_counter)
         self.subscribe(ATTR_ECOMAX_PARAMETERS, self._add_ecomax_parameters)
-        self.subscribe(ATTR_REGDATA, self._decode_regulator_data)
+        self.subscribe(ATTR_REGDATA_DECODER, self._decode_regulator_data)
         self.subscribe(ATTR_MIXER_SENSORS, self._add_mixer_sensors)
         self.subscribe(ATTR_MIXER_PARAMETERS, self._add_mixer_parameters)
         self.subscribe(ATTR_SCHEDULES, self._add_schedules_and_schedule_parameters)
-        self.subscribe_once(ATTR_FRAME_VERSIONS, self._merge_required_frames)
         self.subscribe(ATTR_FRAME_VERSIONS, self._frame_versions.async_update)
+        self.subscribe(ATTR_THERMOSTAT_SENSORS, self._add_thermostat_sensors)
+        self.subscribe(ATTR_THERMOSTAT_PROFILE, self._add_thermostat_profile_parameter)
+        self.subscribe(ATTR_THERMOSTAT_PARAMETERS, self._add_thermostat_parameters)
+        self.subscribe(
+            ATTR_THERMOSTAT_PARAMETERS_DECODER, self._decode_thermostat_parameters
+        )
 
     async def _merge_required_frames(
         self, frame_versions: VersionsInfoType
@@ -98,13 +115,13 @@ class EcoMAX(Device):
         requirements = {int(x): DEFAULT_FRAME_VERSION for x in self.required_frames}
         return {**requirements, **frame_versions}
 
-    def _get_mixer(self, mixer_number: int, total_mixers: int) -> Mixer:
+    def _get_mixer(self, mixer_index: int, total_mixers: int) -> Mixer:
         """Get or create a new mixer object and add it to the device."""
         mixers = self.data.setdefault(ATTR_MIXERS, [])
         try:
-            mixer = mixers[mixer_number]
+            mixer = mixers[mixer_index]
         except IndexError:
-            mixer = Mixer(mixer_number)
+            mixer = Mixer(mixer_index)
             mixers.append(mixer)
             if len(mixers) == total_mixers:
                 # All mixers were processed, notify callbacks and getters.
@@ -112,6 +129,23 @@ class EcoMAX(Device):
 
         return mixer
 
+    def _get_thermostat(
+        self, thermostat_index: int, total_thermostats: int
+    ) -> Thermostat:
+        """Get or create a new thermostat object and add it to the
+        device."""
+        thermostats = self.data.setdefault(ATTR_THERMOSTATS, [])
+        try:
+            thermostat = thermostats[thermostat_index]
+        except IndexError:
+            thermostat = Thermostat(thermostat_index)
+            thermostats.append(thermostat)
+            if len(thermostats) == total_thermostats:
+                # All thermostats were processed, notify callbacks and getters.
+                self.set_device_data(ATTR_THERMOSTATS, thermostats)
+
+        return thermostat
+
     async def _add_ecomax_sensors(self, sensors: DeviceDataType) -> bool:
         """Add ecomax sensor values to the device data."""
         for name, value in sensors.items():
@@ -133,7 +167,7 @@ class EcoMAX(Device):
                 device=self,
                 name=(
                     ECOMAX_P_PARAMETERS[key]
-                    if product.type == ProductTypes.ECOMAX_P
+                    if product.type == ProductType.ECOMAX_P
                     else ECOMAX_I_PARAMETERS[key]
                 ),
                 value=value[0],
@@ -144,22 +178,24 @@ class EcoMAX(Device):
 
         return True
 
-    async def _add_mixer_sensors(self, sensors: Sequence[DeviceDataType]) -> bool:
+    async def _add_mixer_sensors(
+        self, sensors: Sequence[Tuple[int, DeviceDataType]]
+    ) -> bool:
         """Set sensor values for the mixer."""
-        for mixer_number, mixer_data in enumerate(sensors):
-            mixer = self._get_mixer(mixer_number, len(sensors))
-            for name, value in mixer_data.items():
+        for mixer_index, mixer_sensors in sensors:
+            mixer = self._get_mixer(mixer_index, len(sensors))
+            for name, value in mixer_sensors.items():
                 await mixer.async_set_device_data(name, value)
 
         return True
 
     async def _add_mixer_parameters(
-        self, parameters: Sequence[Sequence[Tuple[int, ParameterDataType]]]
+        self, parameters: Sequence[Tuple[int, Sequence[Tuple[int, ParameterDataType]]]]
     ) -> bool:
         """Set mixer parameters."""
         product = await self.get_value(ATTR_PRODUCT)
-        for mixer_number, mixer_parameters in enumerate(parameters):
-            mixer = self._get_mixer(mixer_number, len(parameters))
+        for mixer_index, mixer_parameters in parameters:
+            mixer = self._get_mixer(mixer_index, len(parameters))
             for mixer_parameter in mixer_parameters:
                 index, value = mixer_parameter
                 cls = (
@@ -171,60 +207,116 @@ class EcoMAX(Device):
                     device=self,
                     name=(
                         ECOMAX_P_MIXER_PARAMETERS[index]
-                        if product.type == ProductTypes.ECOMAX_P
+                        if product.type == ProductType.ECOMAX_P
                         else ECOMAX_I_MIXER_PARAMETERS[index]
                     ),
                     value=value[0],
                     min_value=value[1],
                     max_value=value[2],
-                    extra=mixer_number,
+                    extra=mixer_index,
                 )
                 await mixer.async_set_device_data(parameter.name, parameter)
 
         return True
 
+    async def _add_thermostat_sensors(
+        self, sensors: Sequence[Tuple[int, DeviceDataType]]
+    ) -> bool:
+        """Set sensor values for the thermostat."""
+        for thermostat_index, thermostat_sensors in sensors:
+            thermostat = self._get_thermostat(thermostat_index, len(sensors))
+            for name, value in thermostat_sensors.items():
+                await thermostat.async_set_device_data(name, value)
+
+        return True
+
+    async def _add_thermostat_parameters(
+        self, parameters: Sequence[Tuple[int, Sequence[Tuple[int, ParameterDataType]]]]
+    ) -> bool:
+        """Set thermostat parameters."""
+        for thermostat_index, thermostat_parameters in parameters:
+            thermostat = self._get_thermostat(thermostat_index, len(parameters))
+            for thermostat_parameter in thermostat_parameters:
+                index, value = thermostat_parameter
+                cls = (
+                    ThermostatBinaryParameter
+                    if is_binary_parameter(value)
+                    else ThermostatParameter
+                )
+                parameter = cls(
+                    device=self,
+                    name=THERMOSTAT_PARAMETERS[index],
+                    value=value[0],
+                    min_value=value[1],
+                    max_value=value[2],
+                    extra=(thermostat_index * len(thermostat_parameters)),
+                )
+                await thermostat.async_set_device_data(parameter.name, parameter)
+
+        return True
+
+    async def _add_thermostat_profile_parameter(
+        self, parameter: ParameterDataType
+    ) -> Optional[EcomaxParameter]:
+        """Add thermostat profile parameter to the device instance."""
+        if parameter is not None:
+            return EcomaxParameter(
+                device=self,
+                name=ATTR_THERMOSTAT_PROFILE,
+                value=parameter[0],
+                min_value=parameter[1],
+                max_value=parameter[2],
+            )
+
+        return None
+
+    async def _decode_thermostat_parameters(self, decoder: StructureDecoder) -> bool:
+        """Decode thermostat parameters."""
+        data = decoder.decode(decoder.frame.message, data=self.data)[0]
+        for field in (ATTR_THERMOSTAT_PROFILE, ATTR_THERMOSTAT_PARAMETERS):
+            try:
+                await self.async_set_device_data(field, data[field])
+            except KeyError:
+                continue
+
+        return True
+
     async def _add_ecomax_control_parameter(self, mode: int) -> None:
         """Add ecoMAX control parameter to the device instance."""
         parameter = EcomaxBinaryParameter(
             device=self,
-            name=PARAMETER_ECOMAX_CONTROL,
-            value=(mode != 0),
+            name=ATTR_ECOMAX_CONTROL,
+            value=(mode != DeviceState.OFF),
             min_value=0,
             max_value=1,
         )
-        await self.async_set_device_data(PARAMETER_ECOMAX_CONTROL, parameter)
-        await self.async_set_device_data(PARAMETER_BOILER_CONTROL, parameter)
+        await self.async_set_device_data(ATTR_ECOMAX_CONTROL, parameter)
 
-    async def _add_burned_fuel_counter(self, fuel_consumption: int) -> None:
+    async def _add_burned_fuel_counter(self, fuel_consumption: float) -> None:
         """Add burned fuel counter."""
         current_timestamp = time.time()
         seconds_passed = current_timestamp - self._fuel_burned_timestamp
         if 0 <= seconds_passed < MAX_TIME_SINCE_LAST_FUEL_DATA:
             fuel_burned = (fuel_consumption / 3600) * seconds_passed
             await self.async_set_device_data(ATTR_FUEL_BURNED, fuel_burned)
+        else:
+            _LOGGER.warning(
+                "Skipping outdated fuel consumption data, was %i seconds old",
+                seconds_passed,
+            )
 
         self._fuel_burned_timestamp = current_timestamp
 
-    async def _decode_regulator_data(self, regulator_data: bytes) -> DeviceDataType:
-        """Add sensor values from the regulator data."""
-        offset = 0
-        boolean_index = 0
-        regdata: DeviceDataType = {}
-        schema = self.data.get(ATTR_SCHEMA, [])
-        for parameter in schema:
-            parameter_id, parameter_type = parameter
-            if not isinstance(parameter_type, Boolean) and boolean_index > 0:
-                offset += 1
-                boolean_index = 0
+    async def _decode_regulator_data(self, decoder: StructureDecoder) -> bool:
+        """Decode regulator data."""
+        data = decoder.decode(decoder.frame.message, data=self.data)[0]
+        for field in (ATTR_FRAME_VERSIONS, ATTR_REGDATA):
+            try:
+                await self.async_set_device_data(field, data[field])
+            except KeyError:
+                continue
 
-            parameter_type.unpack(regulator_data[offset:])
-            if isinstance(parameter_type, Boolean):
-                boolean_index = parameter_type.index(boolean_index)
-
-            regdata[parameter_id] = parameter_type.value
-            offset += parameter_type.size
-
-        return regdata
+        return True
 
     async def _add_schedules_and_schedule_parameters(
         self, schedules: DeviceDataType
@@ -267,7 +359,7 @@ class EcoMAX(Device):
     async def turn_on(self) -> bool:
         """Turn on the ecoMAX controller."""
         try:
-            return await self.data[PARAMETER_ECOMAX_CONTROL].turn_on()
+            return await self.data[ATTR_ECOMAX_CONTROL].turn_on()
         except KeyError:
             _LOGGER.error("ecoMAX control is not available, please try later")
             return False
@@ -275,16 +367,18 @@ class EcoMAX(Device):
     async def turn_off(self) -> bool:
         """Turn off the ecoMAX controller."""
         try:
-            return await self.data[PARAMETER_ECOMAX_CONTROL].turn_off()
+            return await self.data[ATTR_ECOMAX_CONTROL].turn_off()
         except KeyError:
             _LOGGER.error("ecoMAX control is not available, please try later")
             return False
 
     async def shutdown(self) -> None:
-        """Cancel scheduled tasks."""
-        mixers = self.data.get(ATTR_MIXERS, [])
-        for mixer in mixers:
-            await mixer.shutdown()
+        """Cancel scheduled tasks for root and sub devices."""
+        subdevices = []
+        subdevices.extend(self.data.get(ATTR_MIXERS, []))
+        subdevices.extend(self.data.get(ATTR_THERMOSTATS, []))
+        for subdevice in subdevices:
+            await subdevice.shutdown()
 
         await super().shutdown()
 
