@@ -3,11 +3,11 @@ from __future__ import annotations
 
 from typing import ClassVar
 
-from pyplumio.const import AddressTypes
+from pyplumio.const import DeviceType
 from pyplumio.devices import Device
 
 
 class EcoSTER(Device):
     """Represents ecoSTER thermostat."""
 
-    address: ClassVar[int] = AddressTypes.ECOSTER
+    address: ClassVar[int] = DeviceType.ECOSTER
