@@ -3,10 +3,10 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
-from typing import ClassVar, Dict, Final, List, Optional
+from typing import ClassVar, Dict, Final, Optional
 
 from pyplumio import util
-from pyplumio.const import AddressTypes, FrameTypes
+from pyplumio.const import DeviceType, FrameType
 from pyplumio.exceptions import UnknownFrameError
 from pyplumio.helpers.typing import DeviceDataType, MessageType
 
@@ -31,14 +31,14 @@ def _handler_class_path(frame_type_name: str) -> str:
 # Dictionary of frame handler classes indexed by frame types.
 # example: "24: requests.StopMasterRequest"
 FRAME_TYPES: Dict[int, str] = {
-    frame_type.value: _handler_class_path(frame_type.name) for frame_type in FrameTypes
+    frame_type.value: _handler_class_path(frame_type.name) for frame_type in FrameType
 }
 
 
 def is_known_frame_type(frame_type: int) -> bool:
     """Check if frame type is known."""
     try:
-        FrameTypes(frame_type)
+        FrameType(frame_type)
     except ValueError:
         return False
 
@@ -57,8 +57,8 @@ def get_frame_handler(frame_type: int) -> str:
 class FrameDataClass:
     """Data class mixin for the frame."""
 
-    recipient: int = AddressTypes.BROADCAST
-    sender: int = AddressTypes.ECONET
+    recipient: int = DeviceType.ALL
+    sender: int = DeviceType.ECONET
     sender_type: int = ECONET_TYPE
     econet_version: int = ECONET_VERSION
     message: MessageType = field(default_factory=bytearray)
@@ -75,8 +75,8 @@ class Frame(ABC, FrameDataClass):
         super().__init__(*args, **kwargs)
 
         try:
-            self.sender = AddressTypes(self.sender)
-            self.recipient = AddressTypes(self.recipient)
+            self.sender = DeviceType(self.sender)
+            self.recipient = DeviceType(self.recipient)
         except ValueError:
             pass
 
@@ -92,6 +92,10 @@ class Frame(ABC, FrameDataClass):
         """Return frame length."""
         return self.length
 
+    def hex(self, *args, **kwargs) -> str:
+        """Return hex frame representation."""
+        return self.bytes.hex(*args, **kwargs)
+
     @abstractmethod
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -138,11 +142,6 @@ class Frame(ABC, FrameDataClass):
         data.append(FRAME_END)
         return bytes(data)
 
-    @property
-    def hex(self) -> List[str]:
-        """Return hex frame representation."""
-        return util.to_hex(self.bytes)
-
 
 class Request(Frame):
     """Represents request frame."""
