@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from typing import ClassVar, Optional
 
-from pyplumio.const import ATTR_EXTRA, ATTR_NAME, ATTR_VALUE, FrameTypes
+from pyplumio.const import ATTR_EXTRA, ATTR_INDEX, ATTR_VALUE, FrameType
 from pyplumio.exceptions import FrameDataError
 from pyplumio.frames import Request, Response
 from pyplumio.frames.responses import DeviceAvailableResponse, ProgramVersionResponse
@@ -14,7 +14,7 @@ from pyplumio.structures.schedules import SchedulesStructure
 class ProgramVersionRequest(Request):
     """Represents program version request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_PROGRAM_VERSION
+    frame_type: ClassVar[int] = FrameType.REQUEST_PROGRAM_VERSION
 
     def response(self, **kwargs) -> Optional[Response]:
         """Return response frame object."""
@@ -24,7 +24,7 @@ class ProgramVersionRequest(Request):
 class CheckDeviceRequest(Request):
     """Represents check device request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_CHECK_DEVICE
+    frame_type: ClassVar[int] = FrameType.REQUEST_CHECK_DEVICE
 
     def response(self, **kwargs) -> Optional[Response]:
         """Return response frame object."""
@@ -34,19 +34,19 @@ class CheckDeviceRequest(Request):
 class UIDRequest(Request):
     """Represents uid request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_UID
+    frame_type: ClassVar[int] = FrameType.REQUEST_UID
 
 
 class PasswordRequest(Request):
     """Represents password request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_PASSWORD
+    frame_type: ClassVar[int] = FrameType.REQUEST_PASSWORD
 
 
 class EcomaxParametersRequest(Request):
     """Represents ecoMAX parameters request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_ECOMAX_PARAMETERS
+    frame_type: ClassVar[int] = FrameType.REQUEST_ECOMAX_PARAMETERS
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -59,7 +59,20 @@ class EcomaxParametersRequest(Request):
 class MixerParametersRequest(Request):
     """Represents mixer parameters request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_MIXER_PARAMETERS
+    frame_type: ClassVar[int] = FrameType.REQUEST_MIXER_PARAMETERS
+
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        message = bytearray()
+        message.append(255)  # Number of parameters.
+        message.append(0)  # Index of the first parameter.
+        return message
+
+
+class ThermostatParametersRequest(Request):
+    """Represents thermostat parameters request."""
+
+    frame_type: ClassVar[int] = FrameType.REQUEST_THERMOSTAT_PARAMETERS
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -72,21 +85,21 @@ class MixerParametersRequest(Request):
 class DataSchemaRequest(Request):
     """Represents data schema request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_DATA_SCHEMA
+    frame_type: ClassVar[int] = FrameType.REQUEST_DATA_SCHEMA
 
 
 class SetEcomaxParameterRequest(Request):
     """Represents set ecoMAX parameter request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_SET_ECOMAX_PARAMETER
+    frame_type: ClassVar[int] = FrameType.REQUEST_SET_ECOMAX_PARAMETER
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
         try:
             message = bytearray()
-            name = data[ATTR_NAME]
+            index = data[ATTR_INDEX]
             value = data[ATTR_VALUE]
-            message.append(name)
+            message.append(index)
             message.append(value)
             return message
         except (KeyError, ValueError) as e:
@@ -96,17 +109,36 @@ class SetEcomaxParameterRequest(Request):
 class SetMixerParameterRequest(Request):
     """Represents set mixer parameter request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_SET_MIXER_PARAMETER
+    frame_type: ClassVar[int] = FrameType.REQUEST_SET_MIXER_PARAMETER
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
         try:
-            name = data[ATTR_NAME]
+            index = data[ATTR_INDEX]
             value = data[ATTR_VALUE]
-            mixer_number = data[ATTR_EXTRA]
+            mixer_index = data[ATTR_EXTRA]
             message = bytearray()
-            message.append(mixer_number)
-            message.append(name)
+            message.append(mixer_index)
+            message.append(index)
+            message.append(value)
+            return message
+        except (KeyError, ValueError) as e:
+            raise FrameDataError from e
+
+
+class SetThermostatParameterRequest(Request):
+    """Represents set thermostat parameter request."""
+
+    frame_type: ClassVar[int] = FrameType.REQUEST_SET_THERMOSTAT_PARAMETER
+
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        try:
+            message = bytearray()
+            index = data[ATTR_INDEX]
+            value = data[ATTR_VALUE]
+            offset = data[ATTR_EXTRA]
+            message.append(index if offset is None else index + offset)
             message.append(value)
             return message
         except (KeyError, ValueError) as e:
@@ -116,7 +148,7 @@ class SetMixerParameterRequest(Request):
 class EcomaxControlRequest(Request):
     """Represent ecoMAX control request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_ECOMAX_CONTROL
+    frame_type: ClassVar[int] = FrameType.REQUEST_ECOMAX_CONTROL
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Creates frame message."""
@@ -131,38 +163,38 @@ class EcomaxControlRequest(Request):
 class StartMasterRequest(Request):
     """Represent start master request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_START_MASTER
+    frame_type: ClassVar[int] = FrameType.REQUEST_START_MASTER
 
 
 class StopMasterRequest(Request):
     """Represent stop master request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_STOP_MASTER
+    frame_type: ClassVar[int] = FrameType.REQUEST_STOP_MASTER
 
 
 class AlertsRequest(Request):
     """Represent alerts request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_ALERTS
+    frame_type: ClassVar[int] = FrameType.REQUEST_ALERTS
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
         message = bytearray()
-        message.append(0)  # Index of the first alarm.
-        message.append(100)  # Number of alarms.
+        message.append(0)  # Index of the first alert.
+        message.append(100)  # Number of alerts.
         return message
 
 
 class SchedulesRequest(Request):
     """Represents schedule request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_SCHEDULES
+    frame_type: ClassVar[int] = FrameType.REQUEST_SCHEDULES
 
 
 class SetScheduleRequest(Request):
     """Represents set schedule request."""
 
-    frame_type: ClassVar[int] = FrameTypes.REQUEST_SET_SCHEDULE
+    frame_type: ClassVar[int] = FrameType.REQUEST_SET_SCHEDULE
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         return SchedulesStructure(self).encode(data)
