@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from typing import ClassVar
 
-from pyplumio.const import ATTR_PASSWORD, FrameTypes
+from pyplumio.const import ATTR_PASSWORD, FrameType
 from pyplumio.frames import Response
 from pyplumio.helpers.typing import DeviceDataType, MessageType
 from pyplumio.structures.alerts import AlertsStructure
@@ -14,6 +14,10 @@ from pyplumio.structures.network_info import NetworkInfoStructure
 from pyplumio.structures.product_info import ProductInfoStructure
 from pyplumio.structures.program_version import ProgramVersionStructure
 from pyplumio.structures.schedules import SchedulesStructure
+from pyplumio.structures.thermostat_parameters import (
+    ATTR_THERMOSTAT_PARAMETERS_DECODER,
+    ThermostatParametersStructure,
+)
 
 
 class ProgramVersionResponse(Response):
@@ -21,7 +25,7 @@ class ProgramVersionResponse(Response):
     version info.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_PROGRAM_VERSION
+    frame_type: ClassVar[int] = FrameType.RESPONSE_PROGRAM_VERSION
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -37,7 +41,7 @@ class DeviceAvailableResponse(Response):
     information and status.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_DEVICE_AVAILABLE
+    frame_type: ClassVar[int] = FrameType.RESPONSE_DEVICE_AVAILABLE
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -51,7 +55,7 @@ class DeviceAvailableResponse(Response):
 class UIDResponse(Response):
     """Represents UID response. Contains product and model info."""
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_UID
+    frame_type: ClassVar[int] = FrameType.RESPONSE_UID
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -65,7 +69,7 @@ class UIDResponse(Response):
 class PasswordResponse(Response):
     """Represent password response. Contains device service password."""
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_PASSWORD
+    frame_type: ClassVar[int] = FrameType.RESPONSE_PASSWORD
 
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
@@ -78,7 +82,7 @@ class EcomaxParametersResponse(Response):
     parameters.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_ECOMAX_PARAMETERS
+    frame_type: ClassVar[int] = FrameType.RESPONSE_ECOMAX_PARAMETERS
 
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
@@ -94,19 +98,31 @@ class MixerParametersResponse(Response):
     parameters.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_MIXER_PARAMETERS
+    frame_type: ClassVar[int] = FrameType.RESPONSE_MIXER_PARAMETERS
 
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
         return MixerParametersStructure(self).decode(message)[0]
 
 
-class DataSchemaResponse(Response):
-    """Represents data schema response. Contains schema that describes
-    regdata message structure.
+class ThermostatParametersResponse(Response):
+    """Represents thermostat parameters response. Contains editable
+    thermostat parameters.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_DATA_SCHEMA
+    frame_type: ClassVar[int] = FrameType.RESPONSE_THERMOSTAT_PARAMETERS
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        return {ATTR_THERMOSTAT_PARAMETERS_DECODER: ThermostatParametersStructure(self)}
+
+
+class DataSchemaResponse(Response):
+    """Represents data schema response. Contains schema that describes
+    ecoMAX sensors message structure.
+    """
+
+    frame_type: ClassVar[int] = FrameType.RESPONSE_DATA_SCHEMA
 
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
@@ -118,7 +134,7 @@ class SetEcomaxParameterResponse(Response):
     that aknowledges, that ecoMAX parameter was successfully changed.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_SET_ECOMAX_PARAMETER
+    frame_type: ClassVar[int] = FrameType.RESPONSE_SET_ECOMAX_PARAMETER
 
 
 class SetMixerParameterResponse(Response):
@@ -126,7 +142,15 @@ class SetMixerParameterResponse(Response):
     that aknowledges, that mixer parameter was successfully changed.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_SET_MIXER_PARAMETER
+    frame_type: ClassVar[int] = FrameType.RESPONSE_SET_MIXER_PARAMETER
+
+
+class SetThermostatParameterResponse(Response):
+    """Represents set thermostat parameter response. Empty response
+    that aknowledges, that thermostat parameter was successfully changed.
+    """
+
+    frame_type: ClassVar[int] = FrameType.RESPONSE_SET_THERMOSTAT_PARAMETER
 
 
 class EcomaxControlResponse(Response):
@@ -135,13 +159,13 @@ class EcomaxControlResponse(Response):
     processed.
     """
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_ECOMAX_CONTROL
+    frame_type: ClassVar[int] = FrameType.RESPONSE_ECOMAX_CONTROL
 
 
 class AlertsResponse(Response):
     """Represents device alerts."""
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_ALERTS
+    frame_type: ClassVar[int] = FrameType.RESPONSE_ALERTS
 
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
@@ -151,7 +175,7 @@ class AlertsResponse(Response):
 class SchedulesResponse(Response):
     """Represents device schedule."""
 
-    frame_type: ClassVar[int] = FrameTypes.RESPONSE_SCHEDULES
+    frame_type: ClassVar[int] = FrameType.RESPONSE_SCHEDULES
 
     def decode_message(self, message: MessageType) -> DeviceDataType:
         """Decode frame message."""
