@@ -6,20 +6,14 @@ import asyncio
 import logging
 from typing import TYPE_CHECKING, Any, Final
 
-from pyplumio.const import (
-    ATTR_EXTRA,
-    ATTR_NAME,
-    ATTR_PRODUCT,
-    ATTR_VALUE,
-    STATE_OFF,
-    STATE_ON,
-)
+from pyplumio.const import ATTR_EXTRA, ATTR_INDEX, ATTR_VALUE, STATE_OFF, STATE_ON
 from pyplumio.frames import Request
 from pyplumio.helpers.factory import factory
-from pyplumio.helpers.product_info import ProductTypes
+from pyplumio.helpers.product_info import ProductType
 from pyplumio.helpers.schedule import _collect_schedule_data
 from pyplumio.helpers.typing import ParameterDataType, ParameterValueType
 from pyplumio.structures.ecomax_parameters import (
+    ATTR_ECOMAX_CONTROL,
     ECOMAX_I_PARAMETERS,
     ECOMAX_P_PARAMETERS,
 )
@@ -27,6 +21,11 @@ from pyplumio.structures.mixer_parameters import (
     ECOMAX_I_MIXER_PARAMETERS,
     ECOMAX_P_MIXER_PARAMETERS,
 )
+from pyplumio.structures.product_info import ATTR_PRODUCT
+from pyplumio.structures.thermostat_parameters import (
+    ATTR_THERMOSTAT_PROFILE,
+    THERMOSTAT_PARAMETERS,
+)
 
 if TYPE_CHECKING:
     from pyplumio.devices import Device
@@ -88,17 +87,17 @@ class Parameter(ABC):
         return (
             self.__class__.__name__
             + f"(device={self.device.__class__.__name__}, name={self.name}, "
-            + f"value={self._value}, min_value={self._min_value}, "
-            + f"max_value={self._max_value}, extra={self.extra})"
+            + f"value={self.value}, min_value={self.min_value}, "
+            + f"max_value={self.max_value}, extra={self.extra})"
         )
 
     def _call_relational_method(self, method_to_call, other):
-        func = getattr(self.value, method_to_call)
+        func = getattr(self._value, method_to_call)
         return func(_normalize_parameter_value(other))
 
     def __int__(self) -> int:
         """Return integer representation of parameter value."""
-        return self.value
+        return self._value
 
     def __add__(self, other) -> int:
         """Return result of addition."""
@@ -146,11 +145,10 @@ class Parameter(ABC):
 
     async def set(self, value: ParameterValueType, retries: int = 5) -> bool:
         """Set parameter value."""
-        value = _normalize_parameter_value(value)
-        if value == self._value:
+        if (value := _normalize_parameter_value(value)) == self._value:
             return True
 
-        if value < self.min_value or value > self.max_value:
+        if value < self._min_value or value > self._max_value:
             raise ValueError(
                 f"Parameter value must be between '{self.min_value}' and '{self.max_value}'"
             )
@@ -171,17 +169,17 @@ class Parameter(ABC):
         return True
 
     @property
-    def value(self) -> int:
+    def value(self) -> ParameterValueType:
         """Return parameter value."""
         return self._value
 
     @property
-    def min_value(self) -> int:
+    def min_value(self) -> ParameterValueType:
         """Return minimum allowed value."""
         return self._min_value
 
     @property
-    def max_value(self) -> int:
+    def max_value(self) -> ParameterValueType:
         """Return maximum allowed value."""
         return self._max_value
 
@@ -199,6 +197,21 @@ class Parameter(ABC):
 class BinaryParameter(Parameter):
     """Represents binary device parameter."""
 
+    @property
+    def value(self) -> ParameterValueType:
+        """Return parameter value."""
+        return STATE_ON if self._value == 1 else STATE_OFF
+
+    @property
+    def min_value(self) -> ParameterValueType:
+        """Return minimum allowed value."""
+        return STATE_OFF
+
+    @property
+    def max_value(self) -> ParameterValueType:
+        """Return maximum allowed value."""
+        return STATE_ON
+
     async def turn_on(self) -> bool:
         """Turn parameter on."""
         return await self.set(STATE_ON)
@@ -215,12 +228,23 @@ class EcomaxParameter(Parameter):
     def request(self) -> Request:
         """Return request to change the parameter."""
 
-        if self.name == "ecomax_control":
+        if self.name == ATTR_ECOMAX_CONTROL:
             return factory(
                 "frames.requests.EcomaxControlRequest",
                 recipient=self.device.address,
                 data={
-                    ATTR_VALUE: self.value,
+                    ATTR_VALUE: self._value,
+                },
+            )
+
+        if self.name == ATTR_THERMOSTAT_PROFILE:
+            return factory(
+                "frames.requests.SetThermostatParameterRequest",
+                recipient=self.device.address,
+                data={
+                    ATTR_INDEX: 0,
+                    ATTR_VALUE: self._value,
+                    ATTR_EXTRA: self.extra,
                 },
             )
 
@@ -228,12 +252,12 @@ class EcomaxParameter(Parameter):
             "frames.requests.SetEcomaxParameterRequest",
             recipient=self.device.address,
             data={
-                ATTR_NAME: (
+                ATTR_INDEX: (
                     ECOMAX_P_PARAMETERS.index(self.name)
-                    if self.device.data[ATTR_PRODUCT].type == ProductTypes.ECOMAX_P
+                    if self.device.data[ATTR_PRODUCT].type == ProductType.ECOMAX_P
                     else ECOMAX_I_PARAMETERS.index(self.name)
                 ),
-                ATTR_VALUE: self.value,
+                ATTR_VALUE: self._value,
             },
         )
 
@@ -252,12 +276,12 @@ class MixerParameter(Parameter):
             "frames.requests.SetMixerParameterRequest",
             recipient=self.device.address,
             data={
-                ATTR_NAME: (
+                ATTR_INDEX: (
                     ECOMAX_P_MIXER_PARAMETERS.index(self.name)
-                    if self.device.data[ATTR_PRODUCT].type == ProductTypes.ECOMAX_P
+                    if self.device.data[ATTR_PRODUCT].type == ProductType.ECOMAX_P
                     else ECOMAX_I_MIXER_PARAMETERS.index(self.name)
                 ),
-                ATTR_VALUE: self.value,
+                ATTR_VALUE: self._value,
                 ATTR_EXTRA: self.extra,
             },
         )
@@ -267,6 +291,59 @@ class MixerBinaryParameter(MixerParameter, BinaryParameter):
     """Represents mixer binary parameter."""
 
 
+class ThermostatParameter(Parameter):
+    """Represents thermostat parameter."""
+
+    async def set(self, value: ParameterValueType, retries: int = 5) -> bool:
+        """Set parameter value."""
+        if isinstance(value, (int, float)) and self.name.endswith("target_temp"):
+            value *= 10
+
+        return await super().set(value, retries)
+
+    @property
+    def value(self) -> ParameterValueType:
+        """Return parameter value."""
+        return self._value / 10 if self.name.endswith("target_temp") else self._value
+
+    @property
+    def min_value(self) -> ParameterValueType:
+        """Return minimum allowed value."""
+        return (
+            self._min_value / 10
+            if self.name.endswith("target_temp")
+            else self._min_value
+        )
+
+    @property
+    def max_value(self) -> ParameterValueType:
+        """Return maximum allowed value."""
+        return (
+            self._max_value / 10
+            if self.name.endswith("target_temp")
+            else self._max_value
+        )
+
+    @property
+    def request(self) -> Request:
+        """Return request to change the parameter."""
+        return factory(
+            "frames.requests.SetThermostatParameterRequest",
+            recipient=self.device.address,
+            data={
+                # Increase the index by one to account for thermostat
+                # profile, which is being set at ecoMAX device level.
+                ATTR_INDEX: THERMOSTAT_PARAMETERS.index(self.name) + 1,
+                ATTR_VALUE: self._value,
+                ATTR_EXTRA: self.extra,
+            },
+        )
+
+
+class ThermostatBinaryParameter(MixerParameter, BinaryParameter):
+    """Represents thermostat binary parameter."""
+
+
 class ScheduleParameter(Parameter):
     """Represents schedule parameter."""
 
