@@ -5,7 +5,7 @@ import asyncio
 import logging
 from typing import Awaitable, Callable, Dict, Final, Optional, Tuple
 
-from pyplumio.const import ATTR_NETWORK, AddressTypes, FrameTypes
+from pyplumio.const import DeviceType, FrameType
 from pyplumio.devices import Device, get_device_handler
 from pyplumio.exceptions import (
     FrameError,
@@ -22,6 +22,7 @@ from pyplumio.helpers.network_info import (
 )
 from pyplumio.helpers.task_manager import TaskManager
 from pyplumio.stream import FrameReader, FrameWriter
+from pyplumio.structures.network_info import ATTR_NETWORK
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -143,8 +144,8 @@ class Protocol(TaskManager):
             self.devices[name].handle_frame(frame)
 
             if frame.frame_type in (
-                FrameTypes.REQUEST_CHECK_DEVICE,
-                FrameTypes.REQUEST_PROGRAM_VERSION,
+                FrameType.REQUEST_CHECK_DEVICE,
+                FrameType.REQUEST_PROGRAM_VERSION,
             ):
                 write_queue.put_nowait(
                     frame.response(data={ATTR_NETWORK: self._network})
@@ -159,7 +160,7 @@ class Protocol(TaskManager):
         self.reader = FrameReader(reader)
         self.writer = FrameWriter(writer)
         read_queue, write_queue = self.queues
-        write_queue.put_nowait(StartMasterRequest(recipient=AddressTypes.ECOMAX))
+        write_queue.put_nowait(StartMasterRequest(recipient=DeviceType.ECOMAX))
         lock: asyncio.Lock = asyncio.Lock()
         self.create_task(self.write_consumer(write_queue, lock))
         self.create_task(self.frame_producer(read_queue, lock))
@@ -177,10 +178,9 @@ class Protocol(TaskManager):
 
     async def shutdown(self):
         """Shutdown protocol tasks."""
-        await asyncio.wait([queue.join() for queue in self.queues])
+        await asyncio.gather(*[queue.join() for queue in self.queues])
         self.cancel_tasks()
         await self.wait_until_done()
-
         for device in self.devices.values():
             await device.shutdown()
 
