@@ -2,12 +2,13 @@
 from __future__ import annotations
 
 import math
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import ATTR_FAN_POWER
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import StructureDecoder
+from pyplumio.structures import StructureDecoder, ensure_device_data
+
+ATTR_FAN_POWER: Final = "fan_power"
 
 
 class FanPowerStructure(StructureDecoder):
@@ -18,7 +19,8 @@ class FanPowerStructure(StructureDecoder):
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         fan_power = util.unpack_float(message[offset : offset + 4])[0]
+        offset += 4
         if not math.isnan(fan_power):
-            data[ATTR_FAN_POWER] = fan_power
+            return ensure_device_data(data, {ATTR_FAN_POWER: fan_power}), offset
 
-        return data, offset + 4
+        return ensure_device_data(data), offset
