@@ -1,12 +1,14 @@
 """Contains frame versions structure decoder."""
 from __future__ import annotations
 
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import ATTR_FRAME_VERSIONS
+from pyplumio.const import FrameType
 from pyplumio.helpers.typing import DeviceDataType, VersionsInfoType
-from pyplumio.structures import StructureDecoder, make_device_data
+from pyplumio.structures import StructureDecoder, ensure_device_data
+
+ATTR_FRAME_VERSIONS: Final = "frame_versions"
 
 
 class FrameVersionsStructure(StructureDecoder):
@@ -17,12 +19,17 @@ class FrameVersionsStructure(StructureDecoder):
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         frame_versions: VersionsInfoType = {}
-        frames_number = message[offset]
+        frame_count = message[offset]
         offset += 1
-        for _ in range(frames_number):
+        for _ in range(frame_count):
             frame_type = message[offset]
+            try:
+                frame_type = FrameType(frame_type)
+            except ValueError:
+                pass
+
             version = util.unpack_ushort(message[offset + 1 : offset + 3])
             frame_versions[frame_type] = version
             offset += 3
 
-        return make_device_data(data, {ATTR_FRAME_VERSIONS: frame_versions}), offset
+        return ensure_device_data(data, {ATTR_FRAME_VERSIONS: frame_versions}), offset
