@@ -1,17 +1,18 @@
 """Contains network info structure decoder."""
 from __future__ import annotations
 
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import ATTR_NETWORK
 from pyplumio.helpers.network_info import (
     EthernetParameters,
     NetworkInfo,
     WirelessParameters,
 )
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import Structure, make_device_data
+from pyplumio.structures import Structure, ensure_device_data
+
+ATTR_NETWORK: Final = "network"
 
 
 class NetworkInfoStructure(Structure):
@@ -62,4 +63,4 @@ class NetworkInfoStructure(Structure):
             server_status=bool(message[offset + 25]),
         )
 
-        return make_device_data(data, {ATTR_NETWORK: network_info}), offset
+        return ensure_device_data(data, {ATTR_NETWORK: network_info}), offset
