@@ -2,12 +2,13 @@
 from __future__ import annotations
 
 import math
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import ATTR_POWER
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import StructureDecoder
+from pyplumio.structures import StructureDecoder, ensure_device_data
+
+ATTR_POWER: Final = "power"
 
 
 class PowerStructure(StructureDecoder):
@@ -18,7 +19,8 @@ class PowerStructure(StructureDecoder):
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         power = util.unpack_float(message[offset : offset + 4])[0]
+        offset += 4
         if not math.isnan(power):
-            data[ATTR_POWER] = power
+            return ensure_device_data(data, {ATTR_POWER: power}), offset
 
-        return data, offset + 4
+        return ensure_device_data(data), offset
