@@ -4,17 +4,17 @@ from __future__ import annotations
 from typing import Final, Optional, Tuple
 
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import StructureDecoder, make_device_data
+from pyplumio.structures import StructureDecoder, ensure_device_data
 
-HEATING_TARGET: Final = "heating_target"
-HEATING_STATUS: Final = "heating_status"
-WATER_HEATER_TARGET: Final = "water_heater_target"
-WATER_HEATER_STATUS: Final = "water_heater_status"
+ATTR_HEATING_TARGET: Final = "heating_target"
+ATTR_HEATING_STATUS: Final = "heating_status"
+ATTR_WATER_HEATER_TARGET: Final = "water_heater_target"
+ATTR_WATER_HEATER_STATUS: Final = "water_heater_status"
 STATUSES: Tuple[str, ...] = (
-    HEATING_TARGET,
-    HEATING_STATUS,
-    WATER_HEATER_TARGET,
-    WATER_HEATER_STATUS,
+    ATTR_HEATING_TARGET,
+    ATTR_HEATING_STATUS,
+    ATTR_WATER_HEATER_TARGET,
+    ATTR_WATER_HEATER_STATUS,
 )
 
 
@@ -25,7 +25,7 @@ class StatusesStructure(StructureDecoder):
         self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
-        data = make_device_data(data)
+        data = ensure_device_data(data)
         for index, status in enumerate(STATUSES):
             data[status] = message[offset + index]
 
